@@ -39,9 +39,11 @@ pub(crate) fn build(
 
     let mut stream = TokenStream::default();
 
-    item.expand_item(kind, config)
-        .to_tokens(&mut stream, Span::mixed_site());
-    format_item_errors(errors).to_tokens(&mut stream, Span::mixed_site());
+    let (start, end) = item.block_spans();
+
+    item.expand_item(kind, config, start)
+        .to_tokens(&mut stream, end);
+    format_item_errors(errors).to_tokens(&mut stream, end);
 
     stream.into_token_stream()
 }
